@@ -1,10 +1,13 @@
-"""Error Types"""
+"""Error Types."""
+
 
 class DukeEnergyError(Exception):
     """Base error."""
 
+
 class RequestError(DukeEnergyError):
-    """Error for request issues"""
+    """Error for request issues."""
+
 
 class InputError(DukeEnergyError):
-    """Error for input issues"""
\ No newline at end of file
+    """Error for input issues."""
